@@ -1,23 +1,23 @@
 /******************************************************************************
-  
-  Copyright(c) 2003 - 2004 Intel Corporation. All rights reserved.
-  
-  This program is free software; you can redistribute it and/or modify it 
-  under the terms of version 2 of the GNU General Public License as 
+
+  Copyright(c) 2003 - 2005 Intel Corporation. All rights reserved.
+
+  This program is free software; you can redistribute it and/or modify it
+  under the terms of version 2 of the GNU General Public License as
   published by the Free Software Foundation.
-  
-  This program is distributed in the hope that it will be useful, but WITHOUT 
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or 
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for 
+
+  This program is distributed in the hope that it will be useful, but WITHOUT
+  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
   more details.
-  
+
   You should have received a copy of the GNU General Public License along with
-  this program; if not, write to the Free Software Foundation, Inc., 59 
+  this program; if not, write to the Free Software Foundation, Inc., 59
   Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-  
+
   The full GNU General Public License is included in this distribution in the
   file called LICENSE.
-  
+
   Contact Information:
   James P. Ketrenos <ipw2100-admin@linux.intel.com>
   Intel Corporation, 5200 N.E. Elam Young Parkway, Hillsboro, OR 97124-6497
@@ -46,8 +46,8 @@
 
 #ifndef IRQ_NONE
 typedef void irqreturn_t;
-#define IRQ_NONE 
-#define IRQ_HANDLED 
+#define IRQ_NONE
+#define IRQ_HANDLED
 #define IRQ_RETVAL(x)
 #endif
 
@@ -99,7 +99,7 @@ enum { IPW_DEBUG_ENABLED = 0 };
  * list here in the form of:
  *
  * #define IPW_DL_xxxx VALUE
- * 
+ *
  * shifting value to the left one bit from the previous entry.  xxxx should be
  * the name of the classification (for example, WEP)
  *
@@ -113,7 +113,7 @@ enum { IPW_DEBUG_ENABLED = 0 };
  *
  * you simply need to add your entry to the ipw2100_debug_levels array.
  *
- * If you do not see debug_level in /proc/net/ipw2100 then you do not have 
+ * If you do not see debug_level in /proc/net/ipw2100 then you do not have
  * CONFIG_IPW_DEBUG defined in your kernel configuration
  *
  */
@@ -216,9 +216,9 @@ struct ipw2100_bd {
 	u32 host_addr;
 	u32 buf_length;
 	struct bd_status status;
-        /* number of fragments for frame (should be set only for 
+        /* number of fragments for frame (should be set only for
 	 * 1st TBD) */
-	u8 num_fragments;	
+	u8 num_fragments;
 	u8 reserved[6];
 } __attribute__ ((packed));
 
@@ -247,7 +247,7 @@ struct ipw2100_bd_queue {
 	/* Number of available BDs (invalid for NIC BDs) */
 	u32 available;
 
-	/* Offset of oldest used BD in array (next one to 
+	/* Offset of oldest used BD in array (next one to
 	 * check for completion) */
 	u32 oldest;
 
@@ -342,7 +342,7 @@ struct ipw2100_cmd_header {
 } __attribute__ ((packed));
 
 struct ipw2100_data_header {
-	u32 host_command_reg;	
+	u32 host_command_reg;
 	u32 host_command_reg1;
 	u8 encrypted;	// BOOLEAN in win! TRUE if frame is enc by driver
 	u8 needs_encryption;	// BOOLEAN in win! TRUE if frma need to be enc in NIC
@@ -428,7 +428,7 @@ struct ipw2100_ordinals {
 /* Host Notification header */
 struct ipw2100_notification {
 	u32 hnhdr_subtype;	/* type of host notification */
-	u32 hnhdr_size;		/* size in bytes of data 
+	u32 hnhdr_size;		/* size in bytes of data
 				   or number of entries, if table.
 				   Does NOT include header */
 } __attribute__ ((packed));
@@ -497,8 +497,8 @@ enum {
 #define STATUS_EXIT_PENDING     BIT(14)
 
 #define STATUS_SCAN_PENDING     BIT(23)
-#define STATUS_SCANNING         BIT(24) 
-#define STATUS_SCAN_ABORTING    BIT(25) 
+#define STATUS_SCANNING         BIT(24)
+#define STATUS_SCAN_ABORTING    BIT(25)
 #define STATUS_SCAN_COMPLETE    BIT(26)
 #define STATUS_WX_EVENT_PENDING BIT(27)
 #define STATUS_RESET_PENDING    BIT(29)
@@ -540,7 +540,7 @@ struct ipw2100_priv {
 
 	int stop_hang_check; /* Set 1 when shutting down to kill hang_check */
 	int stop_rf_kill; /* Set 1 when shutting down to kill rf_kill */
-	
+
 	struct ieee80211_device *ieee;
 	unsigned long status;
 	unsigned long config;
@@ -560,9 +560,8 @@ struct ipw2100_priv {
 
 	unsigned long connect_start;
 	unsigned long last_reset;
-	unsigned long start_rx;
 
-	u32 channel_mask; 
+	u32 channel_mask;
 	u32 fatal_error;
 	u32 fatal_errors[IPW2100_ERROR_QUEUE];
 	u32 fatal_index;
@@ -576,13 +575,13 @@ struct ipw2100_priv {
 
 	u8 mandatory_bssid_mac[ETH_ALEN];
 	u8 mac_addr[ETH_ALEN];
-	
+
 	int power_mode;
 
 	/* WEP data */
 	struct ieee80211_security sec;
 	int messages_sent;
-	
+
 
 	int short_retry_limit;
 	int long_retry_limit;
@@ -638,13 +637,12 @@ struct ipw2100_priv {
 	struct work_struct wx_event_work;
 	struct work_struct hang_check;
 	struct work_struct rf_kill;
-	struct work_struct hw_kick;
-	
+
 	u32 interrupts;
 	int tx_interrupts;
 	int rx_interrupts;
 	int inta_other;
-	
+
 	spinlock_t low_lock;
 	struct semaphore action_sem;
 	struct semaphore adapter_sem;
@@ -703,7 +701,7 @@ struct ipw2100_priv {
 #define MSDU_TX_RATES          62
 
 
-// Rogue AP Detection 
+// Rogue AP Detection
 #define SET_STATION_STAT_BITS      64
 #define CLEAR_STATIONS_STAT_BITS   65
 #define LEAP_ROGUE_MODE            66	//TODO tbw replaced by CFG_LEAP_ROGUE_AP
@@ -717,7 +715,7 @@ struct ipw2100_priv {
 //#define IPW_CFG_ANTENNA_SETTING           0x03
 //#define IPW_CFG_ANTENNA_A                 0x01
 //#define IPW_CFG_ANTENNA_B                 0x02
-#define IPW_CFG_PROMISCUOUS         0x00004
+#define IPW_CFG_MONITOR               0x00004
 //#define IPW_CFG_TX_STATUS_ENABLE    0x00008
 #define IPW_CFG_PREAMBLE_AUTO        0x00010
 #define IPW_CFG_IBSS_AUTO_START     0x00020
@@ -731,7 +729,7 @@ struct ipw2100_priv {
 #define IPW_CFG_802_1x_ENABLE       0x04000
 #define IPW_CFG_BSS_MASK		0x08000
 #define IPW_CFG_IBSS_MASK		0x10000
-//#define IPW_CFG_DYNAMIC_CW          0x10000 
+//#define IPW_CFG_DYNAMIC_CW          0x10000
 
 #define IPW_SCAN_NOASSOCIATE BIT(0)
 #define IPW_SCAN_MIXED_CELL BIT(1)
@@ -804,7 +802,7 @@ struct ipw2100_priv {
 #define IPW2100_INTA_TX_TRANSFER               (0x00000001)	// Bit 0 (LSB)
 #define IPW2100_INTA_RX_TRANSFER               (0x00000002)	// Bit 1
 #define IPW2100_INTA_TX_COMPLETE	       (0x00000004)	// Bit 2
-#define IPW2100_INTA_EVENT_INTERRUPT           (0x00000008)     // Bit 3 
+#define IPW2100_INTA_EVENT_INTERRUPT           (0x00000008)     // Bit 3
 #define IPW2100_INTA_STATUS_CHANGE             (0x00000010)	// Bit 4
 #define IPW2100_INTA_BEACON_PERIOD_EXPIRED     (0x00000020)	// Bit 5
 #define IPW2100_INTA_SLAVE_MODE_HOST_COMMAND_DONE  (0x00010000)	// Bit 16
@@ -877,7 +875,7 @@ struct ipw2100_priv {
 #define IPW_WAIT_RESET_MASTER_ASSERT_COMPLETE_DELAY 10	// micro seconds
 
 // BD ring queue read/write difference
-#define IPW_BD_QUEUE_W_R_MIN_SPARE 2	
+#define IPW_BD_QUEUE_W_R_MIN_SPARE 2
 
 #define IPW_CACHE_LINE_LENGTH_DEFAULT		    0x80
 
@@ -915,7 +913,7 @@ struct ipw2100_rx {
 	} rx_data;
 } __attribute__ ((packed));
 
-// Bit 0-7 are for 802.11b tx rates - .  Bit 5-7 are reserved  
+// Bit 0-7 are for 802.11b tx rates - .  Bit 5-7 are reserved
 #define TX_RATE_1_MBIT              0x0001
 #define TX_RATE_2_MBIT              0x0002
 #define TX_RATE_5_5_MBIT            0x0004
@@ -1012,19 +1010,19 @@ typedef enum _ORDINAL_TABLE_1 {	// NS - means Not Supported by FW
 
 	IPW_ORD_STAT_NULL_DATA = 21,	// # of successful NULL data Tx's
 	IPW_ORD_STAT_TX_RTS,	        // # of successful Tx RTS
-	IPW_ORD_STAT_TX_CTS,	        // # of successful Tx CTS            
+	IPW_ORD_STAT_TX_CTS,	        // # of successful Tx CTS
 	IPW_ORD_STAT_TX_ACK,	        // # of successful Tx ACK
-	IPW_ORD_STAT_TX_ASSN,	        // # of successful Association Tx's               
-	IPW_ORD_STAT_TX_ASSN_RESP,	// # of successful Association response Tx's   
-	IPW_ORD_STAT_TX_REASSN,	        // # of successful Reassociation Tx's           
-	IPW_ORD_STAT_TX_REASSN_RESP,	// # of successful Reassociation response Tx's                
-	IPW_ORD_STAT_TX_PROBE,	        // # of probes successfully transmitted 
-	IPW_ORD_STAT_TX_PROBE_RESP,	// # of probe responses successfully transmitted                
-	IPW_ORD_STAT_TX_BEACON,	        // # of tx beacon             
-	IPW_ORD_STAT_TX_ATIM,	        // # of Tx ATIM            
-	IPW_ORD_STAT_TX_DISASSN,	// # of successful Disassociation TX           
-	IPW_ORD_STAT_TX_AUTH,	        // # of successful Authentication Tx                 
-	IPW_ORD_STAT_TX_DEAUTH,	        // # of successful Deauthentication TX                
+	IPW_ORD_STAT_TX_ASSN,	        // # of successful Association Tx's
+	IPW_ORD_STAT_TX_ASSN_RESP,	// # of successful Association response Tx's
+	IPW_ORD_STAT_TX_REASSN,	        // # of successful Reassociation Tx's
+	IPW_ORD_STAT_TX_REASSN_RESP,	// # of successful Reassociation response Tx's
+	IPW_ORD_STAT_TX_PROBE,	        // # of probes successfully transmitted
+	IPW_ORD_STAT_TX_PROBE_RESP,	// # of probe responses successfully transmitted
+	IPW_ORD_STAT_TX_BEACON,	        // # of tx beacon
+	IPW_ORD_STAT_TX_ATIM,	        // # of Tx ATIM
+	IPW_ORD_STAT_TX_DISASSN,	// # of successful Disassociation TX
+	IPW_ORD_STAT_TX_AUTH,	        // # of successful Authentication Tx
+	IPW_ORD_STAT_TX_DEAUTH,	        // # of successful Deauthentication TX
 
 	IPW_ORD_STAT_TX_TOTAL_BYTES = 41,// Total successful Tx data bytes
 	IPW_ORD_STAT_TX_RETRIES,         // # of Tx retries
@@ -1045,37 +1043,37 @@ typedef enum _ORDINAL_TABLE_1 {	// NS - means Not Supported by FW
 
 	// Receive statistics
 	IPW_ORD_STAT_RX_HOST = 61,	// # of packets passed to host
-	IPW_ORD_STAT_RX_DIR_DATA,	// # of directed packets                
-	IPW_ORD_STAT_RX_DIR_DATA1,	// # of directed packets at 1MB            
-	IPW_ORD_STAT_RX_DIR_DATA2,	// # of directed packets at 2MB           
-	IPW_ORD_STAT_RX_DIR_DATA5_5,	// # of directed packets at 5.5MB            
-	IPW_ORD_STAT_RX_DIR_DATA11,	// # of directed packets at 11MB            
-	IPW_ORD_STAT_RX_DIR_DATA22,	// # of directed packets at 22MB            
+	IPW_ORD_STAT_RX_DIR_DATA,	// # of directed packets
+	IPW_ORD_STAT_RX_DIR_DATA1,	// # of directed packets at 1MB
+	IPW_ORD_STAT_RX_DIR_DATA2,	// # of directed packets at 2MB
+	IPW_ORD_STAT_RX_DIR_DATA5_5,	// # of directed packets at 5.5MB
+	IPW_ORD_STAT_RX_DIR_DATA11,	// # of directed packets at 11MB
+	IPW_ORD_STAT_RX_DIR_DATA22,	// # of directed packets at 22MB
 
-	IPW_ORD_STAT_RX_NODIR_DATA = 71,// # of nondirected packets        
-	IPW_ORD_STAT_RX_NODIR_DATA1,	// # of nondirected packets at 1MB            
-	IPW_ORD_STAT_RX_NODIR_DATA2,	// # of nondirected packets at 2MB           
-	IPW_ORD_STAT_RX_NODIR_DATA5_5,	// # of nondirected packets at 5.5MB            
-	IPW_ORD_STAT_RX_NODIR_DATA11,	// # of nondirected packets at 11MB            
+	IPW_ORD_STAT_RX_NODIR_DATA = 71,// # of nondirected packets
+	IPW_ORD_STAT_RX_NODIR_DATA1,	// # of nondirected packets at 1MB
+	IPW_ORD_STAT_RX_NODIR_DATA2,	// # of nondirected packets at 2MB
+	IPW_ORD_STAT_RX_NODIR_DATA5_5,	// # of nondirected packets at 5.5MB
+	IPW_ORD_STAT_RX_NODIR_DATA11,	// # of nondirected packets at 11MB
 
-	IPW_ORD_STAT_RX_NULL_DATA = 80,	// # of null data rx's            
-	IPW_ORD_STAT_RX_POLL,	//NS // # of poll rx                    
-	IPW_ORD_STAT_RX_RTS,	// # of Rx RTS                
-	IPW_ORD_STAT_RX_CTS,	// # of Rx CTS                
-	IPW_ORD_STAT_RX_ACK,	// # of Rx ACK                
-	IPW_ORD_STAT_RX_CFEND,	// # of Rx CF End                
-	IPW_ORD_STAT_RX_CFEND_ACK,	// # of Rx CF End + CF Ack             
-	IPW_ORD_STAT_RX_ASSN,	// # of Association Rx's                    
-	IPW_ORD_STAT_RX_ASSN_RESP,	// # of Association response Rx's            
-	IPW_ORD_STAT_RX_REASSN,	// # of Reassociation Rx's            
-	IPW_ORD_STAT_RX_REASSN_RESP,	// # of Reassociation response Rx's            
-	IPW_ORD_STAT_RX_PROBE,	// # of probe Rx's                
-	IPW_ORD_STAT_RX_PROBE_RESP,	// # of probe response Rx's            
-	IPW_ORD_STAT_RX_BEACON,	// # of Rx beacon            
-	IPW_ORD_STAT_RX_ATIM,	// # of Rx ATIM                    
-	IPW_ORD_STAT_RX_DISASSN,	// # of disassociation Rx            
-	IPW_ORD_STAT_RX_AUTH,	// # of authentication Rx                    
-	IPW_ORD_STAT_RX_DEAUTH,	// # of deauthentication Rx            
+	IPW_ORD_STAT_RX_NULL_DATA = 80,	// # of null data rx's
+	IPW_ORD_STAT_RX_POLL,	//NS // # of poll rx
+	IPW_ORD_STAT_RX_RTS,	// # of Rx RTS
+	IPW_ORD_STAT_RX_CTS,	// # of Rx CTS
+	IPW_ORD_STAT_RX_ACK,	// # of Rx ACK
+	IPW_ORD_STAT_RX_CFEND,	// # of Rx CF End
+	IPW_ORD_STAT_RX_CFEND_ACK,	// # of Rx CF End + CF Ack
+	IPW_ORD_STAT_RX_ASSN,	// # of Association Rx's
+	IPW_ORD_STAT_RX_ASSN_RESP,	// # of Association response Rx's
+	IPW_ORD_STAT_RX_REASSN,	// # of Reassociation Rx's
+	IPW_ORD_STAT_RX_REASSN_RESP,	// # of Reassociation response Rx's
+	IPW_ORD_STAT_RX_PROBE,	// # of probe Rx's
+	IPW_ORD_STAT_RX_PROBE_RESP,	// # of probe response Rx's
+	IPW_ORD_STAT_RX_BEACON,	// # of Rx beacon
+	IPW_ORD_STAT_RX_ATIM,	// # of Rx ATIM
+	IPW_ORD_STAT_RX_DISASSN,	// # of disassociation Rx
+	IPW_ORD_STAT_RX_AUTH,	// # of authentication Rx
+	IPW_ORD_STAT_RX_DEAUTH,	// # of deauthentication Rx
 
 	IPW_ORD_STAT_RX_TOTAL_BYTES = 101,// Total rx data bytes received
 	IPW_ORD_STAT_RX_ERR_CRC,	 // # of packets with Rx CRC error
@@ -1088,112 +1086,112 @@ typedef enum _ORDINAL_TABLE_1 {	// NS - means Not Supported by FW
 	IPW_ORD_STAT_RX_DUPLICATE2,	 // # of duplicate rx packets at 2MB
 	IPW_ORD_STAT_RX_DUPLICATE5_5,	 // # of duplicate rx packets at 5.5MB
 	IPW_ORD_STAT_RX_DUPLICATE11,	 // # of duplicate rx packets at 11MB
-	IPW_ORD_STAT_RX_DUPLICATE = 119, // # of duplicate rx packets            
+	IPW_ORD_STAT_RX_DUPLICATE = 119, // # of duplicate rx packets
 
 	IPW_ORD_PERS_DB_LOCK = 120,	// # locking fw permanent  db
-	IPW_ORD_PERS_DB_SIZE,	// # size of fw permanent  db           
-	IPW_ORD_PERS_DB_ADDR,	// # address of fw permanent  db           
-	IPW_ORD_STAT_RX_INVALID_PROTOCOL,	// # of rx frames with invalid protocol        
-	IPW_ORD_SYS_BOOT_TIME,	// # Boot time 
-	IPW_ORD_STAT_RX_NO_BUFFER,	// # of rx frames rejected due to no buffer 
-	IPW_ORD_STAT_RX_ABORT_LATE_DMA,	//NS // # of rx frames rejected due to dma setup too late    
-	IPW_ORD_STAT_RX_ABORT_AT_HOP,	//NS // # of rx frames aborted due to hop            
-	IPW_ORD_STAT_RX_MISSING_FRAG,	// # of rx frames dropped due to missing fragment            
-	IPW_ORD_STAT_RX_ORPHAN_FRAG,	// # of rx frames dropped due to non-sequential fragment        
-	IPW_ORD_STAT_RX_ORPHAN_FRAME,	// # of rx frames dropped due to unmatched 1st frame            
-	IPW_ORD_STAT_RX_FRAG_AGEOUT,	// # of rx frames dropped due to uncompleted frame        
-	IPW_ORD_STAT_RX_BAD_SSID,	//NS // Bad SSID (unused)            
-	IPW_ORD_STAT_RX_ICV_ERRORS,	// # of ICV errors during decryption        
+	IPW_ORD_PERS_DB_SIZE,	// # size of fw permanent  db
+	IPW_ORD_PERS_DB_ADDR,	// # address of fw permanent  db
+	IPW_ORD_STAT_RX_INVALID_PROTOCOL,	// # of rx frames with invalid protocol
+	IPW_ORD_SYS_BOOT_TIME,	// # Boot time
+	IPW_ORD_STAT_RX_NO_BUFFER,	// # of rx frames rejected due to no buffer
+	IPW_ORD_STAT_RX_ABORT_LATE_DMA,	//NS // # of rx frames rejected due to dma setup too late
+	IPW_ORD_STAT_RX_ABORT_AT_HOP,	//NS // # of rx frames aborted due to hop
+	IPW_ORD_STAT_RX_MISSING_FRAG,	// # of rx frames dropped due to missing fragment
+	IPW_ORD_STAT_RX_ORPHAN_FRAG,	// # of rx frames dropped due to non-sequential fragment
+	IPW_ORD_STAT_RX_ORPHAN_FRAME,	// # of rx frames dropped due to unmatched 1st frame
+	IPW_ORD_STAT_RX_FRAG_AGEOUT,	// # of rx frames dropped due to uncompleted frame
+	IPW_ORD_STAT_RX_BAD_SSID,	//NS // Bad SSID (unused)
+	IPW_ORD_STAT_RX_ICV_ERRORS,	// # of ICV errors during decryption
 
 // PSP Statistics
-	IPW_ORD_STAT_PSP_SUSPENSION = 137,// # of times adapter suspended        
-	IPW_ORD_STAT_PSP_BCN_TIMEOUT,	// # of beacon timeout           
-	IPW_ORD_STAT_PSP_POLL_TIMEOUT,	// # of poll response timeouts       
+	IPW_ORD_STAT_PSP_SUSPENSION = 137,// # of times adapter suspended
+	IPW_ORD_STAT_PSP_BCN_TIMEOUT,	// # of beacon timeout
+	IPW_ORD_STAT_PSP_POLL_TIMEOUT,	// # of poll response timeouts
 	IPW_ORD_STAT_PSP_NONDIR_TIMEOUT,// # of timeouts waiting for last broadcast/muticast pkt
 	IPW_ORD_STAT_PSP_RX_DTIMS,	// # of PSP DTIMs received
 	IPW_ORD_STAT_PSP_RX_TIMS,	// # of PSP TIMs received
 	IPW_ORD_STAT_PSP_STATION_ID,	// PSP Station ID
 
 // Association and roaming
-	IPW_ORD_LAST_ASSN_TIME = 147,	// RTC time of last association               
-	IPW_ORD_STAT_PERCENT_MISSED_BCNS,// current calculation of % missed beacons       
-	IPW_ORD_STAT_PERCENT_RETRIES,	// current calculation of % missed tx retries            
+	IPW_ORD_LAST_ASSN_TIME = 147,	// RTC time of last association
+	IPW_ORD_STAT_PERCENT_MISSED_BCNS,// current calculation of % missed beacons
+	IPW_ORD_STAT_PERCENT_RETRIES,	// current calculation of % missed tx retries
 	IPW_ORD_ASSOCIATED_AP_PTR,	// If associated, this is ptr to the associated
 	// AP table entry. set to 0 if not associated
 	IPW_ORD_AVAILABLE_AP_CNT,	// # of AP's decsribed in the AP table
 	IPW_ORD_AP_LIST_PTR,	// Ptr to list of available APs
-	IPW_ORD_STAT_AP_ASSNS,	// # of associations       
-	IPW_ORD_STAT_ASSN_FAIL,	// # of association failures       
-	IPW_ORD_STAT_ASSN_RESP_FAIL,	// # of failuresdue to response fail       
+	IPW_ORD_STAT_AP_ASSNS,	// # of associations
+	IPW_ORD_STAT_ASSN_FAIL,	// # of association failures
+	IPW_ORD_STAT_ASSN_RESP_FAIL,	// # of failuresdue to response fail
 	IPW_ORD_STAT_FULL_SCANS,	// # of full scans
 
-	IPW_ORD_CARD_DISABLED,	// # Card Disabled 
-	IPW_ORD_STAT_ROAM_INHIBIT,	// # of times roaming was inhibited due to ongoing activity       
+	IPW_ORD_CARD_DISABLED,	// # Card Disabled
+	IPW_ORD_STAT_ROAM_INHIBIT,	// # of times roaming was inhibited due to ongoing activity
 	IPW_FILLER_40,
-	IPW_ORD_RSSI_AT_ASSN = 160,	// RSSI of associated AP at time of association           
+	IPW_ORD_RSSI_AT_ASSN = 160,	// RSSI of associated AP at time of association
 	IPW_ORD_STAT_ASSN_CAUSE1,	// # of reassociations due to no tx from AP in last N
-	// hops or no prob_ responses in last 3 minutes           
-	IPW_ORD_STAT_ASSN_CAUSE2,	// # of reassociations due to poor tx/rx quality            
-	IPW_ORD_STAT_ASSN_CAUSE3,	// # of reassociations due to tx/rx quality with excessive 
-	// load at the AP        
+	// hops or no prob_ responses in last 3 minutes
+	IPW_ORD_STAT_ASSN_CAUSE2,	// # of reassociations due to poor tx/rx quality
+	IPW_ORD_STAT_ASSN_CAUSE3,	// # of reassociations due to tx/rx quality with excessive
+	// load at the AP
 	IPW_ORD_STAT_ASSN_CAUSE4,	// # of reassociations due to AP RSSI level fell below
-	// eligible group             
-	IPW_ORD_STAT_ASSN_CAUSE5,	// # of reassociations due to load leveling            
-	IPW_ORD_STAT_ASSN_CAUSE6,	//NS // # of reassociations due to dropped by Ap            
+	// eligible group
+	IPW_ORD_STAT_ASSN_CAUSE5,	// # of reassociations due to load leveling
+	IPW_ORD_STAT_ASSN_CAUSE6,	//NS // # of reassociations due to dropped by Ap
 	IPW_FILLER_41,
 	IPW_FILLER_42,
 	IPW_FILLER_43,
-	IPW_ORD_STAT_AUTH_FAIL,	// # of times authentication failed        
-	IPW_ORD_STAT_AUTH_RESP_FAIL,	// # of times authentication response failed       
-	IPW_ORD_STATION_TABLE_CNT,	// # of entries in association table        
+	IPW_ORD_STAT_AUTH_FAIL,	// # of times authentication failed
+	IPW_ORD_STAT_AUTH_RESP_FAIL,	// # of times authentication response failed
+	IPW_ORD_STATION_TABLE_CNT,	// # of entries in association table
 
 // Other statistics
 	IPW_ORD_RSSI_AVG_CURR = 173,	// Current avg RSSI
-	IPW_ORD_STEST_RESULTS_CURR,	//NS // Current self test results word       
-	IPW_ORD_STEST_RESULTS_CUM,	//NS // Cummulative self test results word       
-	IPW_ORD_SELF_TEST_STATUS,	//NS //        
-	IPW_ORD_POWER_MGMT_MODE,	// Power mode - 0=CAM, 1=PSP       
-	IPW_ORD_POWER_MGMT_INDEX,	//NS //            
+	IPW_ORD_STEST_RESULTS_CURR,	//NS // Current self test results word
+	IPW_ORD_STEST_RESULTS_CUM,	//NS // Cummulative self test results word
+	IPW_ORD_SELF_TEST_STATUS,	//NS //
+	IPW_ORD_POWER_MGMT_MODE,	// Power mode - 0=CAM, 1=PSP
+	IPW_ORD_POWER_MGMT_INDEX,	//NS //
 	IPW_ORD_COUNTRY_CODE,	// IEEE country code as recv'd from beacon
-	IPW_ORD_COUNTRY_CHANNELS,	// channels suported by country           
+	IPW_ORD_COUNTRY_CHANNELS,	// channels suported by country
 // IPW_ORD_COUNTRY_CHANNELS:
-// For 11b the lower 2-byte are used for channels from 1-14 
+// For 11b the lower 2-byte are used for channels from 1-14
 //   and the higher 2-byte are not used.
-	IPW_ORD_RESET_CNT,	// # of adapter resets (warm)       
-	IPW_ORD_BEACON_INTERVAL,	// Beacon interval       
+	IPW_ORD_RESET_CNT,	// # of adapter resets (warm)
+	IPW_ORD_BEACON_INTERVAL,	// Beacon interval
 
-	IPW_ORD_PRINCETON_VERSION = 184,	//NS // Princeton Version       
-	IPW_ORD_ANTENNA_DIVERSITY,	// TRUE if antenna diversity is disabled       
-	IPW_ORD_CCA_RSSI,	//NS // CCA RSSI value (factory programmed)           
-	IPW_ORD_STAT_EEPROM_UPDATE,	//NS // # of times config EEPROM updated       
-	IPW_ORD_DTIM_PERIOD,	// # of beacon intervals between DTIMs       
+	IPW_ORD_PRINCETON_VERSION = 184,	//NS // Princeton Version
+	IPW_ORD_ANTENNA_DIVERSITY,	// TRUE if antenna diversity is disabled
+	IPW_ORD_CCA_RSSI,	//NS // CCA RSSI value (factory programmed)
+	IPW_ORD_STAT_EEPROM_UPDATE,	//NS // # of times config EEPROM updated
+	IPW_ORD_DTIM_PERIOD,	// # of beacon intervals between DTIMs
 	IPW_ORD_OUR_FREQ,	// current radio freq lower digits - channel ID
 
-	IPW_ORD_RTC_TIME = 190,	// current RTC time           
-	IPW_ORD_PORT_TYPE,	// operating mode       
+	IPW_ORD_RTC_TIME = 190,	// current RTC time
+	IPW_ORD_PORT_TYPE,	// operating mode
 	IPW_ORD_CURRENT_TX_RATE,	// current tx rate
-	IPW_ORD_SUPPORTED_RATES,	// Bitmap of supported tx rates       
+	IPW_ORD_SUPPORTED_RATES,	// Bitmap of supported tx rates
 	IPW_ORD_ATIM_WINDOW,	// current ATIM Window
-	IPW_ORD_BASIC_RATES,	// bitmap of basic tx rates       
-	IPW_ORD_NIC_HIGHEST_RATE,	// bitmap of basic tx rates       
-	IPW_ORD_AP_HIGHEST_RATE,	// bitmap of basic tx rates       
-	IPW_ORD_CAPABILITIES,	// Management frame capability field           
-	IPW_ORD_AUTH_TYPE,	// Type of authentication       
-	IPW_ORD_RADIO_TYPE,	// Adapter card platform type       
-	IPW_ORD_RTS_THRESHOLD = 201,	// Min length of packet after which RTS handshaking is used       
-	IPW_ORD_INT_MODE,	// International mode           
-	IPW_ORD_FRAGMENTATION_THRESHOLD,	// protocol frag threshold       
+	IPW_ORD_BASIC_RATES,	// bitmap of basic tx rates
+	IPW_ORD_NIC_HIGHEST_RATE,	// bitmap of basic tx rates
+	IPW_ORD_AP_HIGHEST_RATE,	// bitmap of basic tx rates
+	IPW_ORD_CAPABILITIES,	// Management frame capability field
+	IPW_ORD_AUTH_TYPE,	// Type of authentication
+	IPW_ORD_RADIO_TYPE,	// Adapter card platform type
+	IPW_ORD_RTS_THRESHOLD = 201,	// Min length of packet after which RTS handshaking is used
+	IPW_ORD_INT_MODE,	// International mode
+	IPW_ORD_FRAGMENTATION_THRESHOLD,	// protocol frag threshold
 	IPW_ORD_EEPROM_SRAM_DB_BLOCK_START_ADDRESS,	// EEPROM offset in SRAM
 	IPW_ORD_EEPROM_SRAM_DB_BLOCK_SIZE,	// EEPROM size in SRAM
-	IPW_ORD_EEPROM_SKU_CAPABILITY,	// EEPROM SKU Capability    206 =  
-	IPW_ORD_EEPROM_IBSS_11B_CHANNELS,	// EEPROM IBSS 11b channel set       
+	IPW_ORD_EEPROM_SKU_CAPABILITY,	// EEPROM SKU Capability    206 =
+	IPW_ORD_EEPROM_IBSS_11B_CHANNELS,	// EEPROM IBSS 11b channel set
 
-	IPW_ORD_MAC_VERSION = 209,	// MAC Version       
-	IPW_ORD_MAC_REVISION,	// MAC Revision       
-	IPW_ORD_RADIO_VERSION,	// Radio Version       
+	IPW_ORD_MAC_VERSION = 209,	// MAC Version
+	IPW_ORD_MAC_REVISION,	// MAC Revision
+	IPW_ORD_RADIO_VERSION,	// Radio Version
 	IPW_ORD_NIC_MANF_DATE_TIME,	// MANF Date/Time STAMP
-	IPW_ORD_UCODE_VERSION,	// Ucode Version       
-	IPW_ORD_HW_RF_SWITCH_STATE = 214,	// HW RF Kill Switch State       
+	IPW_ORD_UCODE_VERSION,	// Ucode Version
+	IPW_ORD_HW_RF_SWITCH_STATE = 214,	// HW RF Kill Switch State
 } ORDINALTABLE1;
 //ENDOF TABLE1
 
@@ -1203,10 +1201,10 @@ typedef enum _ORDINAL_TABLE_1 {	// NS - means Not Supported by FW
 
 typedef enum _ORDINAL_TABLE_2 {	// NS - means Not Supported by FW
 	IPW_ORD_STAT_BASE = 1000,	// contains number of variable ORDs
-	IPW_ORD_STAT_ADAPTER_MAC = 1001,	// 6 bytes: our adapter MAC address  
+	IPW_ORD_STAT_ADAPTER_MAC = 1001,	// 6 bytes: our adapter MAC address
 	IPW_ORD_STAT_PREFERRED_BSSID = 1002,	// 6 bytes: BSSID of the preferred AP
 	IPW_ORD_STAT_MANDATORY_BSSID = 1003,	// 6 bytes: BSSID of the mandatory AP
-	IPW_FILL_1,		//NS // 
+	IPW_FILL_1,		//NS //
 	IPW_ORD_STAT_COUNTRY_TEXT = 1005,	// 36 bytes: Country name text, First two bytes are Country code
 	IPW_ORD_STAT_ASSN_SSID = 1006,	// 32 bytes: ESSID String
 	IPW_ORD_STATION_TABLE = 1007,	// ? bytes: Station/AP table (via Direct SSID Scans)
@@ -1256,12 +1254,7 @@ struct ipw2100_fw_chunk {
 };
 
 struct ipw2100_fw_chunk_set {
-#ifdef CONFIG_IPW2100_LEGACY_FW_LOAD
-	struct list_head chunk_list;
-	unsigned int chunks;
-#else
    	const void *data;
-#endif
 	unsigned long size;
 };
 
@@ -1269,9 +1262,7 @@ struct ipw2100_fw {
 	int version;
 	struct ipw2100_fw_chunk_set fw;
 	struct ipw2100_fw_chunk_set uc;
-#ifndef CONFIG_IPW2100_LEGACY_FW_LOAD
 	const struct firmware *fw_entry;
-#endif
 };
 
 int ipw2100_get_firmware(struct ipw2100_priv *priv, struct ipw2100_fw *fw);
